==> ndiswrapper-1.56-i486-2.6.37.4.txz: usr/src/ndiswrapper-1.56/build-ndiswrapper.sh <==
#!/bin/bash

softversion='1.56'
kernelversion="$(uname -r)"
softname='ndiswrapper'
arch='i486'
cpu='i686'

buildir=$(pwd)

srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"

package="$softname-$softversion-$arch-${kernelversion}"

dest="/tmp/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
#export PKG_CONFIG_PATH=/usr/lib/pkgconfig

cd $src
patch -p0 < $buildir/ndiswrapper-1.56-kernel2.6.36.patch
patch -p1 < $buildir/ndiswrapper-1.56-kernel2.6.36_mc_count.patch
make DESTDIR=$dest
make install DESTDIR=$dest

# Fix this dirty install
mkdir $dest/lib/modules/$kernelversion
mv $dest/lib/modules/misc $dest/lib/modules/$kernelversion

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
ndiswrapper: Ndiswrapper (Win32 network driver API wrapper)
ndiswrapper:
ndiswrapper: Ndiswrapper provides a linux kernel module that loads and runs  
ndiswrapper: Ndis (Win32 network driver API) drivers supplied by the vendors.
ndiswrapper: 
ndiswrapper: 
ndiswrapper: 
ndiswrapper:
ndiswrapper: 
ndiswrapper: 
ndiswrapper:
EODESC

cat << "EOF" > $dest/install/doinst.sh
(depmod -a)
EOF

mkdir -p $dest/usr/doc/$softname-$softversion
cp -a Changelog AUTHORS INSTALL README version $dest/usr/doc/$softname-$softversion/

gzip -9 $dest/usr/man/man?/*

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/src/$softname-$softversion
( cd $buildir
cp -a build-$softname.sh $dest/usr/src/$softname-$softversion/
)

rm -f $dest/lib/modules/$kernelversion/modules.*


cd $dest
makepkg -l y -c n $dest.txz

# cleanup

rm -rf $dest
rm -rf $src

==> ndiswrapper-1.57-i486-3.2.5.txz: usr/src/ndiswrapper-1.57/build-ndiswrapper.sh <==
#!/bin/bash

softversion='1.57'
kernelversion="$(uname -r)"
softname='ndiswrapper'
arch='i486'
cpu='i686'

buildir=$(pwd)

srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"

package="$softname-$softversion-$arch-${kernelversion}"

dest="/tmp/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
#export PKG_CONFIG_PATH=/usr/lib/pkgconfig

cd $src
#patch -p0 < $buildir/ndiswrapper-1.56-kernel2.6.36.patch
#patch -p1 < $buildir/ndiswrapper-1.56-kernel2.6.36_mc_count.patch
make DESTDIR=$dest
make install DESTDIR=$dest

# Fix this dirty install
mkdir $dest/lib/modules/$kernelversion
mv $dest/lib/modules/misc $dest/lib/modules/$kernelversion

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
ndiswrapper: Ndiswrapper (Win32 network driver API wrapper)
ndiswrapper:
ndiswrapper: Ndiswrapper provides a linux kernel module that loads and runs  
ndiswrapper: Ndis (Win32 network driver API) drivers supplied by the vendors.
ndiswrapper: 
ndiswrapper: 
ndiswrapper: 
ndiswrapper:
ndiswrapper: 
ndiswrapper: 
ndiswrapper:
EODESC

cat << "EOF" > $dest/install/doinst.sh
(depmod -a)
EOF

mkdir -p $dest/usr/doc/$softname-$softversion
cp -a Changelog AUTHORS INSTALL README version $dest/usr/doc/$softname-$softversion/

gzip -9 $dest/usr/man/man?/*

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/src/$softname-$softversion
( cd $buildir
cp -a build-$softname.sh $dest/usr/src/$softname-$softversion/
)

rm -f $dest/lib/modules/$kernelversion/modules.*


cd $dest
makepkg -l y -c n $dest.txz

# cleanup

rm -rf $dest
rm -rf $src
